==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedTopicLoadBalancer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedTopicLoadBalancerMBean;
import org.apache.camel.model.LoadBalanceDefinition;
import org.apache.camel.processor.loadbalancer.TopicLoadBalancer;

@ManagedResource(description = "Managed Topic LoadBalancer")
public class ManagedTopicLoadBalancer extends ManagedProcessor implements ManagedTopicLoadBalancerMBean {
    private final TopicLoadBalancer processor;

    public ManagedTopicLoadBalancer(CamelContext context, TopicLoadBalancer processor, LoadBalanceDefinition definition) {
        super(context, processor, definition);
        this.processor = processor;
    }

    @Override
    public Integer getSize() {
        return processor.getProcessors().size();
    }
}

==> apache-camel-4.14.4-src.zip: apache-camel-4.14.4/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedTopicLoadBalancer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedTopicLoadBalancerMBean;
import org.apache.camel.model.LoadBalanceDefinition;
import org.apache.camel.processor.loadbalancer.TopicLoadBalancer;

@ManagedResource(description = "Managed Topic LoadBalancer")
public class ManagedTopicLoadBalancer extends ManagedProcessor implements ManagedTopicLoadBalancerMBean {

    public ManagedTopicLoadBalancer(CamelContext context, TopicLoadBalancer processor, LoadBalanceDefinition definition) {
        super(context, processor, definition);
    }

    @Override
    public TopicLoadBalancer getProcessor() {
        return (TopicLoadBalancer) super.getProcessor();
    }

    @Override
    public Integer getSize() {
        return getProcessor().getProcessors().size();
    }
}
